#! /bin/bash
# =================================================================================================
# SCRIPT extract-godraw-wine.sh		Run godrawvXXX-U.exe in wine			Geoff Kaniuk 22/05/2018
#
# ACKNOWLEGEMENT
# Thanks to John Collins for pioneering running GoDraw in Wine. This script is based on his original
# in Godraw-Linux.tar.gz
#
# COMMAND
# ~/.../GoDraw-Wine$ bash extract-godraw-wine.sh
#
# ACTION
# 	Installs GoDraw in the user's .wine Public directory.  No arguments expected
# =================================================================================================

#										Invocation check										
if [ $(basename $PWD) != "GoDraw-Wine" ] 
then echo "Script $(basename $0) is expected to be in directory GoDraw-Wine"
echo -n "Abort "; read q; exit
fi

#										Library source check
source lib-godraw-wine.sh
if [ ! -v LIB_GODRAW_WINE ]
then echo "Library lib-godraw-wine.sh not loaded"
echo -n "Abort "; read q; exit
fi

#										Sanity check for wine and its Public directory
if_insane_wine_public_abort;
#										Identify latest extractor in path ../GoDraw-Wine
EXTRACTOR=$(ls ../godrawv*-U.exe 2>/dev/null | tail -1)
if [ -z $EXTRACTOR ]
then echo "There is no recognisable extractor  in ../$_GODRAW_WINE."
echo "$_REF_MANUAL" 
now_abort; 
fi

echo "Sanity checks passed - ready to extract $LATEST"
get_reply_yesno "Continue (y/n)? "

#										Extract in wine
echo "will now continue to extract"
cd ..
$_WINE_BIN $(basename $EXTRACTOR)
cd $_GODRAW_WINE

#										Check extraction
WINEGDSYS=$HOME/$_WINE_GDSYS
if [ ! -d $WINEGDSYS ]
then echo "Extraction failed - no directory GoDrawSys in .wine."
echo  $_REF_MANUAL
now_abort
fi

if [ ! -e $WINEGDSYS/GoDraw.exe ]
then echo "Extraction failed - no executable GoDraw.exe in .wine."
echo  $_REF_MANUAL
now_abort
fi

# END extract-godraw-wine.sh
# =================================================================================================

